package bildbearbeitung;

import mediacomputation.Picture;
import mediacomputation.Pixel;

/**
 * Implementation bernommen von
 * http://www.cs.princeton.edu/introcs/31datatype/Rotation.java.html
 * 
 * Implementation ist einfach verstndlich geschrieben, aber nicht optimiert in
 * Bezug auf Aufhrungsgeschwindigkeit oder Speicherverbrauch.
 */
public class BildRotation implements BildBearbeitungInterface {

	@Override
	public Picture bearbeite(Picture originalBild) {
		int breite = originalBild.getWidth();
		int hoehe = originalBild.getHeight();

		double angle = Math.toRadians(45.0);
		double sin = Math.sin(angle);
		double cos = Math.cos(angle);

		double x0 = 0.5 * (breite - 1); // Rotationsmittelpunkt: Bildmitte
		double y0 = 0.5 * (hoehe - 1); // Rotationsmittelpunkt: Bildmitte

		Picture neuesBild = new Picture(breite, hoehe);

		for (int y = 0; y < hoehe; y++) {
			for (int x = 0; x < breite; x++) {
				double a = x - x0;
				double b = y - y0;

				int xx = (int) (+a * cos - b * sin + x0);
				int yy = (int) (+a * sin + b * cos + y0);

				if ((0 <= xx) && (xx < breite) && (0 <= yy) && (yy < hoehe)) {
					Pixel originalPixel = originalBild.getPixel(xx, yy);
					Pixel neuerPixel = neuesBild.getPixel(x, y);
					kopiereFarben(originalPixel, neuerPixel);
				}
			}
		}

		return neuesBild;
	}

	void kopiereFarben(Pixel originalPixel, Pixel neuerPixel) {
		neuerPixel.setRed(originalPixel.getRed());
		neuerPixel.setGreen(originalPixel.getGreen());
		neuerPixel.setBlue(originalPixel.getBlue());
	}
}
