package bildbearbeitung;

import mediacomputation.Picture;
import mediacomputation.Pixel;

/**
 * Implementation bernommen von
 * http://www.cs.princeton.edu/introcs/31datatype/Swirl.java.html bernommen.
 * 
 * Implementation ist einfach verstndlich geschrieben, aber nicht optimiert in
 * Bezug auf Aufhrungsgeschwindigkeit oder Speicherverbrauch.
 */
public class BildSwirl implements BildBearbeitungInterface {

	@Override
	public Picture bearbeite(Picture originalBild) {
		int breite = originalBild.getWidth();
		int hoehe = originalBild.getHeight();

		double x0 = 0.5 * (breite - 1);
		double y0 = 0.5 * (hoehe - 1);

		Picture neuesBild = new Picture(breite, hoehe);

		for (int y = 1; y < hoehe - 1; y++) {
			for (int x = 1; x < breite - 1; x++) {
				double dx = x - x0;
				double dy = y - y0;
				double r = Math.sqrt(dx * dx + dy * dy);
				double angle = Math.PI / 256 * r;
				int tx = (int) (+dx * Math.cos(angle) - dy * Math.sin(angle) + x0);
				int ty = (int) (+dx * Math.sin(angle) + dy * Math.cos(angle) + y0);

				if (tx >= 0 && tx < breite && ty >= 0 && ty < hoehe) {
					Pixel originalPixel = originalBild.getPixel(tx, ty);
					kopiereFarben(originalPixel, neuesBild.getPixel(x, y));
				}
			}
		}

		return neuesBild;
	}

	void kopiereFarben(Pixel originalPixel, Pixel neuerPixel) {
		neuerPixel.setRed(originalPixel.getRed());
		neuerPixel.setGreen(originalPixel.getGreen());
		neuerPixel.setBlue(originalPixel.getBlue());
	}

}
